==> tumbler_0.1.25.orig.tar.bz2: tumbler-0.1.25/plugins/poppler-thumbnailer/poppler-thumbnailer-plugin.c <==
/* vi:set et ai sw=2 sts=2 ts=2: */
/*-
 * Copyright (c) 2010 Jannis Pohlmann <jannis@xfce.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the 
 * GNU Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General 
 * Public License along with this library; if not, write to the 
 * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <glib.h>
#include <glib/gi18n.h>
#include <glib-object.h>

#include <tumbler/tumbler.h>

#include <poppler-thumbnailer/poppler-thumbnailer-provider.h>
#include <poppler-thumbnailer/poppler-thumbnailer.h>



G_MODULE_EXPORT void tumbler_plugin_initialize (TumblerProviderPlugin *plugin);
G_MODULE_EXPORT void tumbler_plugin_shutdown   (void);
G_MODULE_EXPORT void tumbler_plugin_get_types  (const GType          **types,
                                                gint                  *n_types);



static GType type_list[1];



void
tumbler_plugin_initialize (TumblerProviderPlugin *plugin)
{
  const gchar *mismatch;

  /* verify that the tumbler versions are compatible */
  mismatch = tumbler_check_version (TUMBLER_MAJOR_VERSION, TUMBLER_MINOR_VERSION,
                                    TUMBLER_MICRO_VERSION);
  if (G_UNLIKELY (mismatch != NULL))
    {
      g_warning (_("Version mismatch: %s"), mismatch);
      return;
    }

#ifdef DEBUG
  g_message (_("Initializing the Tumbler Poppler PDF/PS Thumbnailer plugin"));
#endif

  /* register the types provided by this plugin */
  poppler_thumbnailer_register (plugin);
  poppler_thumbnailer_provider_register (plugin);

  /* set up the plugin provider type list */
  type_list[0] = TYPE_POPPLER_THUMBNAILER_PROVIDER;
}



void
tumbler_plugin_shutdown (void)
{
#ifdef DEBUG
  g_message (_("Shutting down the Tumbler Pixbuf Thumbnailer plugin"));
#endif
}



void
tumbler_plugin_get_types (const GType **types,
                          gint         *n_types)
{
  *types = type_list;
  *n_types = G_N_ELEMENTS (type_list);
}

==> tumbler-4.18.2.tar.bz2: tumbler-4.18.2/plugins/poppler-thumbnailer/poppler-thumbnailer-plugin.c <==
/* vi:set et ai sw=2 sts=2 ts=2: */
/*-
 * Copyright (c) 2010 Jannis Pohlmann <jannis@xfce.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the 
 * GNU Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General 
 * Public License along with this library; if not, write to the 
 * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <glib.h>
#include <glib/gi18n.h>
#include <glib-object.h>

#include <tumbler/tumbler.h>

#include <poppler-thumbnailer/poppler-thumbnailer-provider.h>
#include <poppler-thumbnailer/poppler-thumbnailer.h>



G_MODULE_EXPORT void tumbler_plugin_initialize (TumblerProviderPlugin *plugin);
G_MODULE_EXPORT void tumbler_plugin_shutdown   (void);
G_MODULE_EXPORT void tumbler_plugin_get_types  (const GType          **types,
                                                gint                  *n_types);



static GType type_list[1];



void
tumbler_plugin_initialize (TumblerProviderPlugin *plugin)
{
  const gchar *mismatch;

  /* verify that the tumbler versions are compatible */
  mismatch = tumbler_check_version (TUMBLER_MAJOR_VERSION, TUMBLER_MINOR_VERSION,
                                    TUMBLER_MICRO_VERSION);
  if (G_UNLIKELY (mismatch != NULL))
    {
      g_warning (TUMBLER_WARNING_VERSION_MISMATCH, mismatch);
      return;
    }

  g_debug ("Initializing the Tumbler Poppler PDF/PS Thumbnailer plugin");

  /* register the types provided by this plugin */
  poppler_thumbnailer_register (plugin);
  poppler_thumbnailer_provider_register (plugin);

  /* set up the plugin provider type list */
  type_list[0] = TYPE_POPPLER_THUMBNAILER_PROVIDER;
}



void
tumbler_plugin_shutdown (void)
{
  g_debug ("Shutting down the Tumbler Poppler PDF/PS Thumbnailer plugin");
}



void
tumbler_plugin_get_types (const GType **types,
                          gint         *n_types)
{
  *types = type_list;
  *n_types = G_N_ELEMENTS (type_list);
}
